@@ -37,7 +37,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     assert_eq!(read_string("1"), "11");
     assert_eq!(read_string("11"), "21");
